@@ -50,6 +50,15 @@ class PackageBuild:
         ])
         self.git_clear_build()
 
+    def pip_install(self):
+        """
+        pip install
+        """
+        logger.info('{} install'.format(self.name))
+        a = run_shell("git remote -v", printf=False)
+        git_url = a.split('\n')[0].split('\t')[1].split(' ')[0]
+        run_shell_list(['pip install git+{}'.format(git_url), ])
+
     def git_clear_build(self):
         logger.info('{} build clear'.format(self.name))
         run_shell_list([
@@ -76,6 +85,7 @@ class PackageBuild:
         ])
         self.git_clear_build()
         self.git_push()
+        self.pip_install()
 
     def git_clean_history(self):
         """
